TokenProgram class

Constructors

TokenProgram()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAssociatedTokenAccountInstruction(Ed25519HDPublicKey funderPubKey, Ed25519HDPublicKey ownerPubKey, Ed25519HDPublicKey mintPubKey) → Future<TransactionInstruction>
Create associated token account instruction
findAssociatedTokenAddress(Ed25519HDPublicKey ownerPubKey, Ed25519HDPublicKey mintPubKey) → Future<Ed25519HDPublicKey>
Find associated token addres
getNumberDecimals(Ed25519HDPublicKey mintAddress, SolanaClient solanaClient) → Future<AccountResult>
getOrCreateAssociatedTokenAccount(Ed25519HDKeyPair ownerKeys, Ed25519HDPublicKey senderPubKey, Ed25519HDPublicKey accountPubKey, SolanaClient solanaClient) → Future<Ed25519HDPublicKey>
Get or create associated token account
getRecentBlockhash(SolanaClient solanaClient) → Future<RecentBlockhashResult>
Get recent blockhash
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareTransaction({required String sourcePrivateKey, required String senderWallet, required String destinationWallet, required int amount, required SolanaClient solanaClient}) → Future<String>
Prepare transaction
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited