ContractServiceImpl class

Inheritance
Annotations
  • @LazySingleton.new(as: ContractService)

Constructors

ContractServiceImpl({required ContractStatusUsecase contractStatusUsecase})

Properties

contractStatusUsecase → ContractStatusUsecase
Path to deliver information from contractRepository
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContractStatus() → Future<AccountResult>
Get Worken status
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited